Crate ntex_util

Crate ntex_util 

Utilities shared by the ntex ecosystem.

This crate provides:

  • channel for local asynchronous communication primitives
  • future for future and stream combinators
  • services for reusable service middleware
  • task for task wake-up and cooperative yielding
  • time for timers, intervals, deadlines, and timeouts

Most types in this crate are designed for ntex’s single-threaded execution model and therefore do not necessarily implement Send or Sync.

Modules

channel
Asynchronous communication primitives.
future
Future and stream utilities.
services
Reusable services and middleware.
task
Task wake-up and scheduling utilities.
time
Utilities for tracking time.

Traits

Stream
A stream of values produced asynchronously.

Functions

clone_io_error
Clones an I/O error’s kind and debug representation.
dyn_err
Boxes an error as a dynamically dispatched error.
dyn_rc_err
Wraps an error in a reference-counted, dynamically dispatched error.
spawn
str_rc_err
Converts a string into a reference-counted error.

Type Aliases

HashMap
A hash map using ntex’s fast, randomly seeded hash state.
HashRandomState
The hash state used by HashMap and HashSet.
HashSet
A hash set using ntex’s fast, randomly seeded hash state.