Inplace

Struct Inplace 

pub struct Inplace<T> { /* private fields */ }
A futures-aware bounded(1) channel.

Implementations

Source

impl<T> Inplace<T>

pub fn send(&self, val: T) -> Result<(), T>

Set a successful result.

If the value is successfully enqueued to be received, then Ok(()) is returned. If the previous value has not been consumed yet, then Err is returned with the value provided.

pub async fn recv(&self) -> T

Waits until a value has been sent and takes it.

pub fn poll_recv(&self, cx: &mut Context<'_>) -> Poll<T>

Polls for a sent value and takes it.