Sender

Struct Sender 

pub struct Sender<T> { /* private fields */ }
The transmission end of a channel.

This is created by the channel function.

Implementations

Source

impl<T> Sender<T>

pub fn send(&self, item: T) -> Result<(), SendError<T>>

Sends the provided message along this channel.

pub fn close(&self)

Closes the channel for every sender.

This prevents any further messages from being sent on the channel, by this sender or any of its clones, while still enabling the receiver to drain messages that are buffered.

pub fn is_closed(&self) -> bool

Returns true if the channel is closed or the receiver has been dropped.

pub fn poll_closed(&self, cx: &mut Context<'_>) -> Poll<()>

Polls whether the channel is closed or the receiver has been dropped.

Only the task from the most recent call is woken, across this sender and all of its clones.

pub async fn closed(&self)

Waits until the channel is closed or the receiver has been dropped.

See poll_closed.