pub type BoxFuture<'a, T> = Pin<Box<dyn Future<Output = T> + 'a>>;Expand description
An owned, dynamically dispatched future.
This is useful when a concrete future type cannot be named or when type erasure is required.
Aliased Type
#[repr(transparent)]pub struct BoxFuture<'a, T> { /* private fields */ }