pub struct Millis(pub u32);Expand description
A Duration type to represent a span of time.
This type is designed for timeouts. Milliseconds resolution is too small to keep generic time.
Tuple Fields
0: u32Implementations